pub trait ValidateWithContext<T> {
// Required method
fn validate_with_context(&self, ctx: &mut Context<'_, T>, path: String);
}Expand description
ValidateWithContext is a trait for validating an object with a context. It allows the object to be validated with additional context information, such as the specification and validation options.