pub struct AuthorizationCodeOAuth2Flow {
pub authorization_url: String,
pub token_url: String,
pub refresh_url: Option<String>,
pub scopes: BTreeMap<String, String>,
pub extensions: Option<BTreeMap<String, Value>>,
}Expand description
Configuration details for the ClientCredentials OAuth Flow
Fields
Required The authorization URL to be used for this flow. This MUST be in the form of a URL.
token_url: StringRequired The token URL to be used for this flow. This MUST be in the form of a URL.
refresh_url: Option<String>The URL to be used for obtaining refresh tokens. This MUST be in the form of a URL.
scopes: BTreeMap<String, String>Required The available scopes for the OAuth2 security scheme. A map between the scope name and a short description for it. The map MAY be empty.
extensions: Option<BTreeMap<String, Value>>This object MAY be extended with Specification Extensions.
The field name MUST begin with x-, for example, x-internal-id.
The value can be null, a primitive, an array or an object.