Reference Object
Structs
- Ref
- Ref is a simple object to allow referencing other components in the OpenAPI document, internally and externally. The $ref string value contains a URI RFC3986, which identifies the location of the value being referenced. See the rules for resolving Relative References.
Enums
- RefOr
- RefOr is a simple object to allow storing a reference to another component or a component itself.
- Resolve
Error - ResolveError is an error type for resolving references.
Traits
- Resolve
Reference - ResolveReference is a trait for resolving references.